
Error handling on trusted devices
-------

**Description:**

Whenever error handling is not applied through trusted devices the errors it supplies can 
not be trusted since they can be tampered with.


**Solution:**

Verify that all error handling is performed on trusted devices.
	